package
Version:
v1.54.2
Opens a new window with list of versions in this module.
Published: Apr 20, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 25
Opens a new window with list of known importers.
Documentation
¶
type CreateRequest struct {
CheckpointID string
CheckpointDir string
Exit bool
}
CreateRequest holds parameters to create a checkpoint from a container.
type Summary struct {
Name string
}
Summary represents the details of a checkpoint when listing endpoints.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.