registry

package
v1.53.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 26, 2026 License: Apache-2.0 Imports: 3 Imported by: 60

Documentation

Index

Constants

const AuthHeader = "X-Registry-Auth"

AuthHeader is the name of the header used to send encoded registry authorization credentials for registry operations (push/pull).

Variables

This section is empty.

Functions

This section is empty.

Types

type AuthConfig

type AuthConfig struct {
	Username string `json:"username,omitempty"`
	Password string `json:"password,omitempty"`
	Auth     string `json:"auth,omitempty"`

	ServerAddress string `json:"serveraddress,omitempty"`

	// IdentityToken is used to authenticate the user and get
	// an access token for the registry.
	IdentityToken string `json:"identitytoken,omitempty"`

	// RegistryToken is a bearer token to be sent to a registry
	RegistryToken string `json:"registrytoken,omitempty"`
}

AuthConfig contains authorization information for connecting to a Registry.

type AuthResponse

type AuthResponse struct {

	// An opaque token used to authenticate a user after a successful login
	// Example: 9cbaf023786cd7...
	IdentityToken string `json:"IdentityToken,omitempty"`

	// The status of the authentication
	// Example: Login Succeeded
	// Required: true
	Status string `json:"Status"`
}

AuthResponse An identity token was generated successfully.

swagger:model AuthResponse

type DistributionInspect

type DistributionInspect struct {
	// Descriptor contains information about the manifest, including
	// the content addressable digest
	Descriptor ocispec.Descriptor
	// Platforms contains the list of platforms supported by the image,
	// obtained by parsing the manifest
	Platforms []ocispec.Platform
}

DistributionInspect describes the result obtained from contacting the registry to retrieve image metadata

type IndexInfo

type IndexInfo struct {
	// Name is the name of the registry, such as "docker.io"
	Name string
	// Mirrors is a list of mirrors, expressed as URIs
	Mirrors []string
	// Secure is set to false if the registry is part of the list of
	// insecure registries. Insecure registries accept HTTP and/or accept
	// HTTPS with certificates from unknown CAs.
	Secure bool
	// Official indicates whether this is an official registry
	Official bool
}

IndexInfo contains information about a registry

RepositoryInfo Examples:

{
  "Index" : {
    "Name" : "docker.io",
    "Mirrors" : ["https://registry-2.docker.io/v1/", "https://registry-3.docker.io/v1/"],
    "Secure" : true,
    "Official" : true,
  },
  "RemoteName" : "library/debian",
  "LocalName" : "debian",
  "CanonicalName" : "docker.io/debian"
  "Official" : true,
}

{
  "Index" : {
    "Name" : "127.0.0.1:5000",
    "Mirrors" : [],
    "Secure" : false,
    "Official" : false,
  },
  "RemoteName" : "user/repo",
  "LocalName" : "127.0.0.1:5000/user/repo",
  "CanonicalName" : "127.0.0.1:5000/user/repo",
  "Official" : false,
}

type RequestAuthConfig

type RequestAuthConfig func(context.Context) (string, error)

RequestAuthConfig is a function interface that clients can supply to retry operations after getting an authorization error.

The function must return the AuthHeader value (AuthConfig), encoded in base64url format (RFC4648, section 5), which can be decoded by [DecodeAuthConfig].

It must return an error if the privilege request fails.

type SearchResult

type SearchResult struct {
	// StarCount indicates the number of stars this repository has
	StarCount int `json:"star_count"`
	// IsOfficial is true if the result is from an official repository.
	IsOfficial bool `json:"is_official"`
	// Name is the name of the repository
	Name string `json:"name"`
	// IsAutomated indicates whether the result is automated.
	//
	// Deprecated: the "is_automated" field is deprecated and will always be "false".
	IsAutomated bool `json:"is_automated"`
	// Description is a textual description of the repository
	Description string `json:"description"`
}

SearchResult describes a search result returned from a registry

type SearchResults

type SearchResults struct {
	// Query contains the query string that generated the search results
	Query string `json:"query"`
	// NumResults indicates the number of results the query returned
	NumResults int `json:"num_results"`
	// Results is a slice containing the actual results for the search
	Results []SearchResult `json:"results"`
}

SearchResults lists a collection search results returned from a registry

type ServiceConfig

type ServiceConfig struct {
	InsecureRegistryCIDRs []netip.Prefix        `json:"InsecureRegistryCIDRs"`
	IndexConfigs          map[string]*IndexInfo `json:"IndexConfigs"`
	Mirrors               []string
}

ServiceConfig stores daemon registry services configuration.

Jump to