storage

package
v1.54.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 0 Imported by: 7

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DriverData

type DriverData struct {

	// Low-level storage metadata, provided as key/value pairs.
	//
	// This information is driver-specific, and depends on the storage-driver
	// in use, and should be used for informational purposes only.
	//
	// Example: {"MergedDir":"/var/lib/docker/overlay2/ef749362d13333e65fc95c572eb525abbe0052e16e086cb64bc3b98ae9aa6d74/merged","UpperDir":"/var/lib/docker/overlay2/ef749362d13333e65fc95c572eb525abbe0052e16e086cb64bc3b98ae9aa6d74/diff","WorkDir":"/var/lib/docker/overlay2/ef749362d13333e65fc95c572eb525abbe0052e16e086cb64bc3b98ae9aa6d74/work"}
	// Required: true
	Data map[string]string `json:"Data"`

	// Name of the storage driver.
	// Example: overlay2
	// Required: true
	Name string `json:"Name"`
}

DriverData Information about the storage driver used to store the container's and image's filesystem.

swagger:model DriverData

type RootFSStorage

type RootFSStorage struct {

	// Information about the snapshot used for the container's root filesystem.
	//
	Snapshot *RootFSStorageSnapshot `json:"Snapshot,omitempty"`
}

RootFSStorage Information about the storage used for the container's root filesystem.

swagger:model RootFSStorage

type RootFSStorageSnapshot

type RootFSStorageSnapshot struct {

	// Name of the snapshotter.
	Name string `json:"Name,omitempty"`
}

RootFSStorageSnapshot Information about a snapshot backend of the container's root filesystem.

swagger:model RootFSStorageSnapshot

type Storage

type Storage struct {

	// Information about the storage used for the container's root filesystem.
	//
	RootFS *RootFSStorage `json:"RootFS,omitempty"`
}

Storage Information about the storage used by the container.

swagger:model Storage

Jump to