strslice

package
v1.54.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: Apache-2.0 Imports: 0 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type StrSlice deprecated

type StrSlice = []string

StrSlice represents a string or an array of strings.

Deprecated: this type was used for compatibility with deprecated API versions. Use []string instead.

Jump to